@@ -230,14 +230,15 @@ def cli_qa_update_quota(obj):
 @qa.command("list", help="List QA envs for user: all to show qa of all users.")
 @click.option("-u", "--user", "user", required=False)
 @click.option("-s", "--status", "status", multiple=True, type=str)
+@click.option("-c", "--card", "card", type=str)
 @click.pass_obj
-def cli_qa_list(obj, user, status):
+def cli_qa_list(obj, user, status, card):
     QA(
         "list",
         obj["project"],
         obj["config"],
         obj["tokens"],
-        {"user": user, "status": status},
+        {"user": user, "status": status, "card": card},
     ).run()
 
 
