@@ -5,6 +5,7 @@ import requests
 from github.GithubException import UnknownObjectException
 from halo import Halo
 from suite_py.lib.handler.github_handler import GithubHandler
+from suite_py.lib.handler.git_handler import GitHandler
 from suite_py.lib.handler import prompt_utils
 from suite_py.lib import logger
 
@@ -37,12 +38,14 @@ class QainitHandler:
         "external": ["create:qa", "delete:qa", "describe:qa", "list:qa", "update:qa"],
     }
 
-    def __init__(self, config, tokens):
+    def __init__(self, project, config, tokens):
+        self._project = project
         self._token = tokens.drone
         self._config = config
         self.url = self._config.qainit["url"]
         self.auth0_token = self._config.get_cache("auth0_token")
         self._github = GithubHandler(tokens)
+        self._git = GitHandler(project, config)
 
         if "url" not in config.qainit:
             self.usage()
@@ -58,6 +61,7 @@ class QainitHandler:
 
     def create_services_body(self, prj_list):
         srv_list = []
+        ref = self._git.current_branch_name()
         for prj in prj_list:
             with Halo(text="Loading branches...", spinner="dots", color="magenta"):
                 choices = [
@@ -67,7 +71,7 @@ class QainitHandler:
             if choices:
                 choices.sort(key=lambda x: x["name"])
                 ref = prompt_utils.ask_choices(
-                    f"Select branch for project - {prj}: ", choices
+                    f"Select branch for project - {prj}: ", choices, default_text=ref
                 )
             try:
                 self._github.get_raw_content(prj, ref, ".service.yml")
